unit DRUSMARCtoMySQL;
interface

uses
  SysUtils, Classes;

type
  TTDRUSMARCtoMySQLProcessEvent=Function (Progress, MaxValue:Integer):Integer Of Object;

  TDRUSMARCtoMySQL = class
  private
    { Private declarations }
    FRUSMARCFile, FMySQLFile:TStringList;

    FRUSMARCFileName, FMySQLFileName:String;
    FDatabaseName, FTableName:String;
    FRUSMARCPos:Integer;
    FAddSlashes:Boolean;
    FProcessEvent:TTDRUSMARCtoMySQLProcessEvent;

  protected
    { Protected declarations }
    Procedure OpenFiles;
    Procedure CloseFiles;

    Function DoAddSlashes(S:String):String;
    Function ReadString:String;
    Function ReadRecord:String;
    Procedure WriteString(S:String);

  public
    { Public declarations }
    Constructor Create;
    Destructor Destroy; override;

    Function Convert:Integer;
    Property OnProcess:TTDRUSMARCtoMySQLProcessEvent read FProcessEvent write FProcessEvent;

    Property RUSMARCFileName:String read FRUSMARCFileName write FRUSMARCFileName;
    Property MySQLFileName:String read FMySQLFileName write FMySQLFileName;
    Property DatabaseName:String read FDatabaseName write FDatabaseName;
    Property TableName:String read FTableName write FTableName;
    Property AddSlashes:Boolean read FAddSlashes write FAddSlashes;
  end;


implementation

Constructor TDRUSMARCtoMySQL.Create;
Begin
  inherited Create;
  FRUSMARCFile:=TStringList.Create;
  FMySQLFile:=TStringList.Create;
  FAddSlashes:=True;
  FProcessEvent:=nil;
End;

Destructor TDRUSMARCtoMySQL.Destroy;
Begin
  FRUSMARCFile.Free;
  FMySQLFile.Free;
//  inherited Free;
End;

Procedure TDRUSMARCtoMySQL.OpenFiles;
Begin
  FRUSMARCFile.Clear;
  FRUSMARCFile.LoadFromFile(FRUSMARCFileName);
  FMySQLFile.Clear;
End;

Procedure TDRUSMARCtoMySQL.CloseFiles;
Begin
  FRUSMARCFile.Clear;
  FMySQLFile.SaveToFile(FMySQLFileName);
  FMySQLFile.Clear;
End;

Function TDRUSMARCtoMySQL.DoAddSlashes(S:String):String;
Var
  i:Integer;
  Prefix, Data:String;
Begin
  Result:=S;
  If ((S='') Or (S[Length(S)]<>'''')) Then Exit;

  Prefix:=Copy(S, 1, Pos('''', S));
  Delete(S, 1, Pos('''', S));
  Delete(S, Length(S), 1);
  Data:='';
  For i:=1 To Length(S) Do
  Begin
    If ((S[i]='''') Or (S[i]='\')) Then
      Data:=Data+'\'+S[i]
    Else
      Data:=Data+S[i];
  End;

  Result:=Prefix+Data+'''';
End;

Function TDRUSMARCtoMySQL.ReadString:String;
Begin
  Result:='';
  If FRUSMARCPos>=FRUSMARCFile.Count Then Exit;
  Result:=FRUSMARCFile.Strings[FRUSMARCPos];
  Inc(FRUSMARCPos);
  Delete(Result, 1, Pos(' ', Result));
  If FAddSlashes Then Result:=DoAddSlashes(Result);
End;

Function TDRUSMARCtoMySQL.ReadRecord:String;
Var
  S:String;
Begin
  Result:='';
  S:=ReadString;
  While ((S<>'') And (S<>'*****')) Do
  Begin
    If Result='' Then Result:=S Else Result:=Result+', '+S;
    S:=ReadString;
  End;
End;

Procedure TDRUSMARCtoMySQL.WriteString(S:String);
Begin
  FMySQLFile.Add(S);
End;

Function TDRUSMARCtoMySQL.Convert:Integer;
Var
  S, Rec:String;
Begin
  FRUSMARCPos:=0;
  FTableName:=Trim(FTableName);
  FDatabaseName:=Trim(FDatabaseName);
  If FTableName='' Then
  Begin
    Result:=-1;
    Exit;
  End;

  OpenFiles;
  If Assigned(FProcessEvent) Then FProcessEvent(FRUSMARCPos, FRUSMARCFile.Count-1);

// ,   
  If FDatabaseName<>'' Then
  Begin
    S:='USE '+FDatabaseName+';';
    WriteString(S);
  End;

// 
  Rec:=ReadRecord;
  If Assigned(FProcessEvent) Then FProcessEvent(FRUSMARCPos, FRUSMARCFile.Count-1);
  While Rec<>'' Do
  Begin
    S:='INSERT INTO '+FTableName;
    WriteString(S);
    S:='  SET '+Rec+';';
    WriteString(S);

    Rec:=ReadRecord;
    If Assigned(FProcessEvent) Then
      If FProcessEvent(FRUSMARCPos, FRUSMARCFile.Count-1)<>0 Then Break;
  End;

  CloseFiles;
  Result:=0;
End;

end.
